@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ import (
 	"reflect"
 	"testing"
 
-	"golang.zabbix.com/sdk/zbxerr"
+	"git.zabbix.com/ap/plugin-support/zbxerr"
 )
 
 func Test_collectionsDiscoveryHandler(t *testing.T) {
